package com.example

import com.google.devtools.ksp.processing.KSPLogger
import com.google.devtools.ksp.processing.Resolver
import com.google.devtools.ksp.processing.SymbolProcessor
import com.google.devtools.ksp.processing.SymbolProcessorEnvironment
import com.google.devtools.ksp.processing.SymbolProcessorProvider
import com.google.devtools.ksp.symbol.KSAnnotated
import com.google.devtools.ksp.symbol.KSClassDeclaration
import com.google.devtools.ksp.symbol.KSTypeAlias

class ExampleProcessor(
    private val logger: KSPLogger
) : SymbolProcessor {
    override fun process(resolver: Resolver): List<KSAnnotated> {
        val symbols = resolver.getSymbolsWithAnnotation(ExampleAnnotation::class.qualifiedName!!)

        for (symbol in symbols) {
            if (symbol is KSClassDeclaration) {
                val exampleClass =
                    symbol.getAllProperties()
                        .first().type.resolve().declaration as KSClassDeclaration

                exampleClass
                    .primaryConstructor
                    ?.parameters
                    ?.find { it.name?.getShortName() == "foo" }
                    ?.let { param ->
                        logger.error("isTypeAlias(${param.type.resolve().declaration is KSTypeAlias}) - ${param.type}")
                    }
            }
        }

        return emptyList()
    }
}

class ExampleProcessorProvider : SymbolProcessorProvider {
    override fun create(environment: SymbolProcessorEnvironment): SymbolProcessor {
        return ExampleProcessor(
            environment.logger
        )
    }
}
